@@ -22,26 +22,22 @@ LearnerRegrSVM = R6Class("LearnerRegrSVM",
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
-      ps = ParamSet$new(list(
-        ParamFct$new("type",
-          default = "eps-regression",
-          levels = c("eps-regression", "nu-regression"), tags = "train"),
-        ParamFct$new("kernel", default = "radial", levels = c(
-          "linear", "polynomial",
-          "radial", "sigmoid"), tags = "train"),
-        ParamInt$new("degree", default = 3L, lower = 1L, tags = "train"),
-        ParamDbl$new("coef0", default = 0, tags = "train"),
-        ParamDbl$new("cost", default = 1, lower = 0, tags = "train"),
-        ParamDbl$new("nu", default = 0.5, tags = "train"),
-        ParamDbl$new("gamma", lower = 0, tags = "train"),
-        ParamDbl$new("cachesize", default = 40L, tags = "train"),
-        ParamDbl$new("tolerance", default = 0.001, lower = 0, tags = "train"),
-        ParamDbl$new("epsilon", lower = 0, tags = "train"),
-        ParamLgl$new("shrinking", default = TRUE, tags = "train"),
-        ParamInt$new("cross", default = 0L, lower = 0L, tags = "train"), # tunable = FALSE),
-        ParamLgl$new("fitted", default = TRUE, tags = "train"), # tunable = FALSE),
-        ParamUty$new("scale", default = TRUE, tags = "train") # , tunable = TRUE)
-      ))
+      ps = ps(
+        cachesize = p_dbl(default = 40L, tags = "train"),
+        coef0     = p_dbl(default = 0, tags = "train"),
+        cost      = p_dbl(0, default = 1, tags = "train"),
+        cross     = p_int(0L, default = 0L, tags = "train"), # tunable = FALSE),
+        degree    = p_int(1L, default = 3L, tags = "train"),
+        epsilon   = p_dbl(0, tags = "train"),
+        gamma     = p_dbl(0, tags = "train"),
+        kernel    = p_fct(c("linear", "polynomial", "radial", "sigmoid"), default = "radial", tags = "train"),
+        nu        = p_dbl(default = 0.5, tags = "train"),
+        shrinking = p_lgl(default = TRUE, tags = "train"),
+        tolerance = p_dbl(0, default = 0.001, tags = "train"),
+        type      = p_fct(c("eps-regression", "nu-regression"), default = "eps-regression", tags = "train"),
+        fitted    = p_lgl(default = TRUE, tags = "train"), # tunable = FALSE),
+        scale     = p_uty(default = TRUE, tags = "train") # , tunable = TRUE)
+      )
       ps$add_dep("cost", "type", CondEqual$new("eps-regression"))
       ps$add_dep("nu", "type", CondEqual$new("nu-regression"))
       ps$add_dep("degree", "kernel", CondEqual$new("polynomial"))
@@ -61,18 +57,18 @@ LearnerRegrSVM = R6Class("LearnerRegrSVM",
 
   private = list(
     .train = function(task) {
-      pars = self$param_set$get_values(tags = "train")
+      pv = self$param_set$get_values(tags = "train")
       data = as_numeric_matrix(task$data(cols = task$feature_names))
       self$state$feature_names = colnames(data)
 
-      invoke(e1071::svm, x = data, y = task$truth(), .args = pars)
+      invoke(e1071::svm, x = data, y = task$truth(), .args = pv)
     },
 
     .predict = function(task) {
-      pars = self$param_set$get_values(tags = "predict")
+      pv = self$param_set$get_values(tags = "predict")
       newdata = as_numeric_matrix(task$data(cols = task$feature_names))
       newdata = newdata[, self$state$feature_names, drop = FALSE]
-      response = invoke(predict, self$model, newdata = newdata, type = "response", .args = pars)
+      response = invoke(predict, self$model, newdata = newdata, type = "response", .args = pv)
       list(response = response)
     }
   )
